Package 'deductive'

Title: Data Correction and Imputation Using Deductive Methods
Description: Attempt to repair inconsistencies and missing values in data records by using information from valid values and validation rules restricting the data.
Authors: Mark van der Loo [cre, aut] (ORCID: <https://orcid.org/0000-0002-9807-4686>), Edwin de Jonge [aut] (ORCID: <https://orcid.org/0000-0002-6580-4718>), Reijer Idema [ctb]
Maintainer: Mark van der Loo <[email protected]>
License: GPL-3
Version: 1.0.1
Built: 2026-05-09 07:34:44 UTC
Source: https://github.com/data-cleaning/deductive

Help Index